@@ -15,13 +15,11 @@
 SRWL=/sbin/shorewall6
 SRWL_OPTS="-tvv"
 WAIT_FOR_IFUP=/usr/share/shorewall6/wait4ifup
-# Note, set INITLOG to /dev/null if you do not want to
-# keep logs of the firewall (not recommended)
-INITLOG=/var/log/shorewall6-init.log
+test -n ${INITLOG:=/var/log/shorewall6-init.log}
 
 test -x $SRWL || exit 0
 test -x $WAIT_FOR_IFUP || exit 0
-test -n $INITLOG || {
+test -n "$INITLOG" || {
 	echo "INITLOG cannot be empty, please configure $0" ; 
 	exit 1;
 }
@@ -55,7 +53,7 @@ not_configured () {
 	exit 0
 }
 
-# check if shorewall6 is configured or not
+# check if shorewall is configured or not
 if [ -f "/etc/default/shorewall6" ]
 then
 	. /etc/default/shorewall6
@@ -68,6 +66,10 @@ else
 	not_configured
 fi
 
+[ "$INITLOG" = "/dev/null" ] && SHOREWALL_INIT_SCRIPT=1 || SHOREWALL_INIT_SCRIPT=0
+
+export SHOREWALL_INIT_SCRIPT
+
 # wait for an unconfigured interface 
 wait_for_pppd () {
 	if [ "$wait_interface" != "" ]
