@@ -4,7 +4,7 @@
 #
 #     This program is under GPL [http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt]
 #
-#     (c) 2000,2001,2002,2003,2004,2005,2008 - Tom Eastep (teastep@shorewall.net)
+#     (c) 2000,2001,2002,2003,2004,2005,2008,2009,2010 - Tom Eastep (teastep@shorewall.net)
 #
 #       Shorewall documentation is available at http://shorewall.net
 #
@@ -22,7 +22,7 @@
 #       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-VERSION=4.2.10
+VERSION=4.4.6
 
 usage() # $1 = exit status
 {
@@ -30,7 +30,6 @@ usage() # $1 = exit status
     echo "usage: $ME"
     echo "       $ME -v"
     echo "       $ME -h"
-    echo "       $ME -n"
     exit $1
 }
 
@@ -76,41 +75,6 @@ cant_autostart()
     echo  "WARNING: Unable to configure shorewall6 to start automatically at boot" >&2
 }
 
-backup_directory() # $1 = directory to backup
-{
-    if [ -d $1 ]; then
-	if cp -a $1  ${1}-${VERSION}.bkout ; then
-	    echo
-	    echo "$1 saved to ${1}-${VERSION}.bkout"
-	else
-	    exit 1
-	fi
-    fi
-}
-
-backup_file() # $1 = file to backup, $2 = (optional) Directory in which to create the backup
-{
-    if [ -z "${PREFIX}{NOBACKUP}" ]; then
-	if [ -f $1 -a ! -f ${1}-${VERSION}.bkout ]; then
-	    if [ -n "$2" ]; then
-		if [ -d $2 ]; then
-		    if cp -f $1 $2 ; then
-			echo
-			echo "$1 saved to $2/$(basename $1)"
-		    else
-			exit 1
-		    fi
-		fi
-	    elif cp $1 ${1}-${VERSION}.bkout; then
-		echo
-		echo "$1 saved to ${1}-${VERSION}.bkout"
-	    else
-		exit 1
-	    fi
-	fi
-    fi
-}
-
 delete_file() # $1 = file to delete
 {
     rm -f $1
@@ -121,12 +85,6 @@ install_file() # $1 = source $2 = target $3 = mode
     run_install $OWNERSHIP -m $3 $1 ${2}
 }
 
-install_file_with_backup() # $1 = source $2 = target $3 = mode $4 = (optional) backup directory
-{
-    backup_file $2 $4
-    run_install $OWNERSHIP -m $3 $1 ${2}
-}
-
 #
 # Parse the run line
 #
@@ -155,8 +113,11 @@ MANDIR=${MANDIR:-"/usr/share/man"}
 
 case $(uname) in
     CYGWIN*)
-	DEST=
-	INIT=
+	if [ -z "$PREFIX" ]; then
+	    DEST=
+	    INIT=
+	fi
+
 	OWNER=$(id -un)
 	GROUP=$(id -gn)
 	CYGWIN=Yes
@@ -169,8 +130,6 @@ esac
 
 OWNERSHIP="-o $OWNER -g $GROUP"
 
-NOBACKUP=
-
 while [ $# -gt 0 ] ; do
     case "$1" in
 	-h|help|?)
@@ -180,9 +139,6 @@ while [ $# -gt 0 ] ; do
 	    echo "Shorewall6 Firewall Installer Version $VERSION"
 	    exit 0
 	    ;;
-	-n)
-	    NOBACKUP=Yes
-	    ;;
 	*)
 	    usage 1
 	    ;;
@@ -203,13 +159,15 @@ if [ -n "$PREFIX" ]; then
 	    echo "Not setting file owner/group permissions, not running as root."
 	    OWNERSHIP=""
 	fi    
-
-	install -d $OWNERSHIP -m 755 ${PREFIX}/sbin
-	install -d $OWNERSHIP -m 755 ${PREFIX}${DEST}
     fi
+	
+    install -d $OWNERSHIP -m 755 ${PREFIX}/sbin
+    install -d $OWNERSHIP -m 755 ${PREFIX}${DEST}
+   
+    CYGWIN=
 else
-    [ -x /usr/share/shorewall-perl/compiler.pl ] || \
-	{ echo "   ERROR: Shorewall-perl is not installed" >&2; exit 1; }
+    [ -x /usr/share/shorewall/compiler.pl ] || \
+	{ echo "   ERROR: Shorewall >= 4.3.5 is not installed" >&2; exit 1; }
     if [ -z "$CYGWIN" ]; then
 	if [ -d /etc/apt -a -e /usr/bin/dpkg ]; then
 	    DEBIAN=yes
@@ -237,20 +195,15 @@ echo "Installing Shorewall6 Version $VERSION"
 #
 if [ -d ${PREFIX}/etc/shorewall6 ]; then
     first_install=""
-    if [ -z "$NOBACKUP" ]; then
-	backup_directory ${PREFIX}/etc/shorewall6
-	backup_directory ${PREFIX}/usr/share/shorewall6
-	backup_directory ${PREFIX}/var/lib/shorewall6
-    fi
 else
     first_install="Yes"
 fi
 
 if [ -z "$CYGWIN" ]; then
-   install_file_with_backup shorewall6 ${PREFIX}/sbin/shorewall6 0755 ${PREFIX}/var/lib/shorewall6-${VERSION}.bkout
+   install_file shorewall6 ${PREFIX}/sbin/shorewall6 0755 ${PREFIX}/var/lib/shorewall6-${VERSION}.bkout
    echo "shorewall6 control program installed in ${PREFIX}/sbin/shorewall6"
 else
-   install_file_with_backup shorewall6 ${PREFIX}/bin/shorewall6 0755 ${PREFIX}/var/lib/shorewall6-${VERSION}.bkout
+   install_file shorewall6 ${PREFIX}/bin/shorewall6 0755 ${PREFIX}/var/lib/shorewall6-${VERSION}.bkout
    echo "shorewall6 control program installed in ${PREFIX}/bin/shorewall6"
 fi
 
@@ -259,13 +212,13 @@ fi
 # Install the Firewall Script
 #
 if [ -n "$DEBIAN" ]; then
-    install_file_with_backup init.debian.sh /etc/init.d/shorewall6 0544 ${PREFIX}/usr/share/shorewall6-${VERSION}.bkout
+    install_file init.debian.sh /etc/init.d/shorewall6 0544 ${PREFIX}/usr/share/shorewall6-${VERSION}.bkout
 elif [ -n "$SLACKWARE" ]; then
-    install_file_with_backup init.slackware.shorewall6.sh ${PREFIX}${DEST}/rc.shorewall6 0544 ${PREFIX}/usr/share/shorewall6-${VERSION}.bkout
+    install_file init.slackware.shorewall6.sh ${PREFIX}${DEST}/rc.shorewall6 0544 ${PREFIX}/usr/share/shorewall6-${VERSION}.bkout
 elif [ -n "$ARCHLINUX" ]; then
-    install_file_with_backup init.archlinux.sh ${PREFIX}${DEST}/$INIT 0544 ${PREFIX}/usr/share/shorewall6-${VERSION}.bkout
+    install_file init.archlinux.sh ${PREFIX}${DEST}/$INIT 0544 ${PREFIX}/usr/share/shorewall6-${VERSION}.bkout
 elif [ -n "$INIT" ]; then
-    install_file_with_backup init.sh ${PREFIX}${DEST}/$INIT 0544 ${PREFIX}/usr/share/shorewall6-${VERSION}.bkout
+    install_file init.sh ${PREFIX}${DEST}/$INIT 0544 ${PREFIX}/usr/share/shorewall6-${VERSION}.bkout
 fi
 
 [ -n "$CYGWIN" ] || echo  "Shorewall6 script installed in ${PREFIX}${DEST}/$INIT"
@@ -281,6 +234,12 @@ mkdir -p ${PREFIX}/var/lib/shorewall6
 chmod 755 ${PREFIX}/etc/shorewall6
 chmod 755 ${PREFIX}/usr/share/shorewall6
 chmod 755 ${PREFIX}/usr/share/shorewall6/configfiles
+
+if [ -n "$PREFIX" ]; then
+    mkdir -p ${PREFIX}/etc/logrotate.d
+    chmod 755 ${PREFIX}/etc/logrotate.d
+fi
+
 #
 # Install the config file
 #
@@ -557,6 +516,51 @@ if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall6/restored ]; then
     echo "Restored file installed as ${PREFIX}/etc/shorewall6/restored"
 fi
 #
+# Install the Clear file
+#
+run_install $OWNERSHIP -m 0644 clear ${PREFIX}/usr/share/shorewall6/configfiles/clear
+
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall6/clear ]; then
+    run_install $OWNERSHIP -m 0600 clear ${PREFIX}/etc/shorewall6/clear
+    echo "Clear file installed as ${PREFIX}/etc/shorewall6/clear"
+fi
+#
+# Install the Isusable file
+#
+run_install $OWNERSHIP -m 0644 isusable ${PREFIX}/usr/share/shorewall6/configfiles/isusable
+
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall6/isusable ]; then
+    run_install $OWNERSHIP -m 0600 isusable ${PREFIX}/etc/shorewall6/isusable
+    echo "Isusable file installed as ${PREFIX}/etc/shorewall/isusable"
+fi
+#
+# Install the Refresh file
+#
+run_install $OWNERSHIP -m 0644 refresh ${PREFIX}/usr/share/shorewall6/configfiles/refresh
+
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall6/refresh ]; then
+    run_install $OWNERSHIP -m 0600 refresh ${PREFIX}/etc/shorewall6/refresh
+    echo "Refresh file installed as ${PREFIX}/etc/shorewall6/refresh"
+fi
+#
+# Install the Refreshed file
+#
+run_install $OWNERSHIP -m 0644 refreshed ${PREFIX}/usr/share/shorewall6/configfiles/refreshed
+
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall6/refreshed ]; then
+    run_install $OWNERSHIP -m 0600 refreshed ${PREFIX}/etc/shorewall6/refreshed
+    echo "Refreshed file installed as ${PREFIX}/etc/shorewall6/refreshed"
+fi
+#
+# Install the Tcclear file
+#
+run_install $OWNERSHIP -m 0644 tcclear ${PREFIX}/usr/share/shorewall6/configfiles/tcclear
+
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall6/tcclear ]; then
+    run_install $OWNERSHIP -m 0600 tcclear ${PREFIX}/etc/shorewall6/tcclear
+    echo "Tcclear file installed as ${PREFIX}/etc/shorewall6/tcclear"
+fi
+#
 # Install the Standard Actions file
 #
 install_file actions.std ${PREFIX}/usr/share/shorewall6/actions.std 0644
@@ -644,6 +648,11 @@ cd ..
 
 echo "Man Pages Installed"
 
+if [ -d ${PREFIX}/etc/logrotate.d ]; then
+    run_install $OWNERSHIP -m 0644 logrotate ${PREFIX}/etc/logrotate.d/shorewall6
+    echo "Logrotate file installed as ${PREFIX}/etc/logrotate.d/shorewall6"
+fi
+
 if [ -z "$PREFIX" -a -n "$first_install" -a -z "$CYGWIN" ]; then
     if [ -n "$DEBIAN" ]; then
 	run_install $OWNERSHIP -m 0644 default.debian /etc/default/shorewall6
